library(testthat)
library(mapme.biodiversity)

options(pillar.advice = FALSE)
test_check("mapme.biodiversity")
